__title__ = "mathy_pydoc"
__version__ = "0.7.20"
__summary__ = "Minimal python API documentation generation for https://mathy.ai"
__uri__ = "https://github.com/mathy/mathy_pydoc"
__author__ = "Justin DuJardin"
__email__ = "justin@dujardinconsulting.com"
__license__ = "MIT"
